
* DKdis04.do - Exercises, Set 9
* Ecological inference using the latent structure approach
* Adapted from DKdis02.do and DKdis03.do

use "m:\stata\DKdistricts.dta", clear

* Preparing data
*****************

* Inspect DP9
*sum dpoe98-votdp98

* Compute percent of all votes for all parties
foreach v of varlist dpoe98 dpf98 dpu98 dpa98 dpb98 dpd98 dpq98 dpc98 /*
  */ dpv98 dpo98 dpz98 xdp98 spldp98 absdp98 {
gen p`v' = `v'/votdp98*100 
  }

* Weighted percentages
sum pdpoe98-pabsdp98 [aw=votdp98]

* Compute logit shares for all parties
foreach v of varlist dpoe98 dpf98 dpu98 dpa98 dpb98 dpd98 dpq98 dpc98 /*
  */ dpv98 dpo98 dpz98 xdp98 spldp98 absdp98 {
gen l`v' = ln(p`v'/(100-p`v')) 
  }
sum ldpoe98-labsdp98 [aw=votdp98]

* Compute percentages and logits for DP 2001
********************************************

* Inspect DP01
*sum dpoe01-votdp01

* Compute percentages for all parties
foreach v of varlist dpoe01 dpf01 dpa01 dpb01 dpd01 dpq01 dpc01 /*
  */ dpv01 dpo01 dpz01 xdp01 spldp01 absdp01 {
gen p`v' = `v'/votdp01*100 
  }
sum pdpoe01-pabsdp01 [aw=votdp01]

* Compute logits for all parties
foreach v of varlist dpoe01 dpf01 dpa01 dpb01 dpd01 dpq01 dpc01 /*
  */ dpv01 dpo01 dpz01 xdp01 spldp01 absdp01 {
gen l`v' = ln(p`v'/(100-p`v')) 
  }
sum ldpoe01-labsdp01 [aw=votdp01]

* Compute socio-economic variables
**********************************

*income
gen lincom99 = ln(incom99)/1000000
sum lincom99

* Country of origin: Western
gen pwstor99 = wstor99/popor99*100
gen lwstor99 = ln(pwstor99/(100-pwstor99))/1000000
sum pwstor99 lwstor99 [aw=popor99]

* Occupation
* Compute percentages for all occupation 1999
foreach v of varlist ocfar99-ocret99 {
gen p`v' = `v'/votep99*100 
  }
sum poc*99 [aw=votep99]

* Compute logits for all occupations 1999
foreach v of varlist ocfar99-ocret99 {
gen l`v' = ln(p`v'/(100-p`v'))/1000000 
  }
sum loc*99 [aw=votep99]

* Education
* Compute percentage for all educations 1998
foreach v of varlist edbas98-hghed98 {
gen p`v' = `v'/poped98*100 
  }
sum pedbas98-phghed98 [aw=poped98]

* Compute logits for all educations 1998
foreach v of varlist edbas98-hghed98 {
gen l`v' = ln(p`v'/(100-p`v'))/1000000 
  }
sum ledbas98-lhghed98 [aw=poped98]

* Voting dichotomies

* Absolute numbers and pct voting for socialist parties
egen validvot98 = rsum(dpoe98 - xdp98)
gen soc98 = dpoe98+dpf98+dpa98
gen nso98 = validvot98 - soc98
gen psoc98 = soc98/validvot98*100

egen validvot01 = rsum(dpoe01 - xdp01)
gen soc01 = dpoe01+dpf01+dpa01
gen nso01 = validvot01 - soc01
gen psoc01 = soc01/validvot01*100

* Pct non socialist voters
gen pnso98 = 100 - psoc98
gen pnso01 = 100 - psoc01

* Logits
gen lsoc98 = ln(psoc98/(100-psoc98))
gen lsoc01 = ln(psoc01/(100-psoc01))

* Class dichotomies

* Pct working class voters 1999
gen wrk99 = oclwc99+ocwrk99+ocupl99
gen mid99 = votep99-ocret99-wrk99
gen pwrk99 = wrk99/(wrk99+mid99)*100

* pct middle class voters 1999
gen pmid99 = 100 - pwrk99

* Logit
gen lwrk = ln(pwrk99/(100-pwrk99))

* Ecological inference using regression
***************************************

* 2 x 2 tables

* Voter transitions

* Simple regression analysis weighted by unit size
*regress psoc01 psoc98 [aweight=validvot01 ]

* Get coefficients
*matrix coefs = e(b)
*gen a = coefs[1,2]
*gen b = coefs[1,1]
*gen pct = (_n-1)/(_N-1)*100
*gen tendency = a + b*pct

* Draw symmetric scattergram
*twoway (scatter psoc01 psoc98, sort) (line tendency pct, sort clpat(solid)),/*
*/ ytitle(Socialist parties 2001: Pct, margin(medsmall)) yscale(range(0 100))/*
*/ xtitle(Socialist parties 1998: Pct, margin(medsmall)) xscale(range(0 100))/*
*/ xlabel(0(10) 100, grid) legend(off) ysize(4) xsize(5)/* 
*/ ylabel(0(10) 100, grid) legend(off)/* 
*/graphregion(fcolor(white) lcolor(black))
*drop a b pct tendency

* Direct estimates of transition proportions

* Voter transitions to soc 2001
*regress psoc01 psoc98 pnso98 [aweight=validvot01], noconstant

* Voter transitions to non soc 2001
*regress pnso01 psoc98 pnso98 [aweight=validvot01], noconstant


* Ecological inference using ecol
*********************************
* Preparing errors-in-variables regression

* find correlation
correlate lsoc98 lsoc01 [aweight=validvot01 ]

* Errors-in-variables regression analysis weighted by unit size
eivreg lsoc01 lsoc98 [aweight=validvot01], reliab(lsoc98 `r(rho)')

* Get coefficients
matrix coefs = e(b)
gen a = coefs[1,2]
gen b = coefs[1,1]
gen pct = (_n-0.99)/(_N-0.98)*100
gen logit = ln(pct/(100-pct))
gen tendency = a + b*logit
replace tendency = exp(tendency)/(1+exp(tendency))*100

* Draw symmetric scattergram
twoway (scatter psoc01 psoc98, sort) (line tendency pct, sort clpat(solid)),/*
*/ ytitle(Socialist parties 2001: Pct, margin(medsmall)) yscale(range(0 100))/*
*/ xtitle(Socialist parties 1998: Pct, margin(medsmall)) xscale(range(0 100))/*
*/ xlabel(0(10) 100, grid) legend(off) ysize(4) xsize(5)/* 
*/ ylabel(0(10) 100, grid) legend(off)/* 
*/graphregion(fcolor(white) lcolor(black))

gen region2 = region

* Draw symmetric scattergram with region code
*twoway (scatter psoc01 psoc98, sort msymbol(none) mlabel(region2)/* 
*/ mlabposition(0))(line tendency pct, sort clpat(solid)),/*
*/ ytitle(Socialist parties 2001: Pct, margin(medsmall)) yscale(range(0 100))/*
*/ xtitle(Socialist parties 1998: Pct, margin(medsmall)) xscale(range(0 100))/*
*/ xlabel(0(10) 100, grid) legend(off) ysize(4) xsize(5)/*
*/ ylabel(0(10) 100, grid) legend(off)/*  
*/graphregion(fcolor(white) lcolor(black))

drop a b pct tendency region2

* Estimation with ecol
ecol soc98 nso98/ soc01 nso01

* How can we get row percentages?
help ecol

* Order row percentages from now on
ecol pct rows

* Repeat the first ecol command
ecol soc98 nso98/ soc01 nso01

* Do separate estimate for each region and add together
bysort region : ecol soc98 nso98 / soc01 nso01

* Class voting

* Regression method

* Simple regression analysis weighted by unit size
*regress psoc98 pwrk99 [aweight=validvot98]

* Get coefficients
*matrix coefs = e(b)
*gen a = coefs[1,2]
*gen b = coefs[1,1]
*gen pct = (_n-1)/(_N-1)*100
*gen tendency = a + b*pct

* Draw symmetric scattergram
*twoway (scatter psoc98 pwrk99, sort) (line tendency pct, sort clpat(solid)),/*
*/ ytitle(Socialist parties 1998: Pct, margin(medsmall)) yscale(range(0 100))/*
*/ xtitle(Working class: Pct, margin(medsmall)) xscale(range(0 100))/*
*/ xlabel(0(10) 100, grid) legend(off) ysize(4) xsize(5)/* 
*/ ylabel(0(10) 100, grid) legend(off)/* 
*/graphregion(fcolor(white) lcolor(black))
*drop a b tendency

* Class and socialist vote 1998
*regress psoc98 pwrk99 pmid99 [aweight=validvot98 ], noconstant

* Class and non socialist vote 1998
*regress pnso98 pwrk99 pmid99 [aweight=validvot98 ], noconstant

* Class and socialist vote 2001
*regress psoc01 pwrk99 pmid99 [aweight=validvot01 ], noconstant

* Class and non socialist vote 2001
*regress pnso01 pwrk99 pmid99 [aweight=validvot01 ], noconstant

* Ecol method
bysort region : ecol wrk99 mid99 / soc98 nso98


* m x n tables

* Regression method

* Multi-party voter transitions
*foreach v of varlist dpoe01 dpf01 dpa01 dpb01 dpd01 dpq01 dpc01 /*
  */ dpv01 dpo01 dpz01 absdp01 {
*regress p`v' pdpoe98 pdpf98 pdpa98-pdpz98 pabsdp98 [aweight=votdp01 ], noconstant 
*  }

* Multi-party class voting
*foreach v of varlist dpoe01 dpf01 dpa01 dpb01 dpd01 dpq01 dpc01 /*
  */ dpv01 dpo01 dpz01 absdp01 {
*regress p`v' pocfar99-pocret99 [aweight=votdp01 ], noconstant 
*  }

* Ecol method (remember to widen the Stata Results window)

* Multi-party voter transitions
bysort region : ecol dpoe98-absdp98 / dpoe01-absdp01

* Multi-party class voting
bysort region : ecol ocfar99-ocret99 / dpoe01-absdp01
